/******************************************************************************
  This source file is part of the Avogadro project.
  This source code is released under the 3-Clause BSD License, (see "LICENSE").
******************************************************************************/

#include "transformnode.h"

namespace Avogadro::Rendering {

TransformNode::TransformNode(GroupNode* p) : GroupNode(p) {}

TransformNode::~TransformNode() {}

} // namespace Avogadro::Rendering
